# coding: utf-8

# flake8: noqa

"""
    WASM OJ Wonderland API

    You can interact with WASM OJ Wonderland through this API  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: jacob@csie.cool
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


__version__ = "0.0.1"

# import apis into sdk package
from woj.api.auth_api import AuthApi
from woj.api.problem_api import ProblemApi
from woj.api.submission_api import SubmissionApi
from woj.api.default_api import DefaultApi

# import ApiClient
from woj.api_response import ApiResponse
from woj.api_client import ApiClient
from woj.configuration import Configuration
from woj.exceptions import OpenApiException
from woj.exceptions import ApiTypeError
from woj.exceptions import ApiValueError
from woj.exceptions import ApiKeyError
from woj.exceptions import ApiAttributeError
from woj.exceptions import ApiException

# import models into sdk package
from woj.models.api_auth_get200_response import ApiAuthGet200Response
from woj.models.api_auth_send_post200_response import ApiAuthSendPost200Response
from woj.models.api_auth_send_post400_response import ApiAuthSendPost400Response
from woj.models.api_auth_send_post_request import ApiAuthSendPostRequest
from woj.models.api_me_get200_response import ApiMeGet200Response
from woj.models.api_problem_get200_response import ApiProblemGet200Response
from woj.models.api_problem_get200_response_problems_inner import ApiProblemGet200ResponseProblemsInner
from woj.models.api_problem_id_get200_response import ApiProblemIdGet200Response
from woj.models.api_problem_id_get200_response_problem import ApiProblemIdGet200ResponseProblem
from woj.models.api_problem_id_get200_response_problem_policy_inner import ApiProblemIdGet200ResponseProblemPolicyInner
from woj.models.api_problem_id_get200_response_problem_testcase_inner import ApiProblemIdGet200ResponseProblemTestcaseInner
from woj.models.api_submission_get200_response import ApiSubmissionGet200Response
from woj.models.api_submission_get200_response_submissions_inner import ApiSubmissionGet200ResponseSubmissionsInner
from woj.models.api_submission_id_get200_response import ApiSubmissionIdGet200Response
from woj.models.api_submission_id_get200_response_submission import ApiSubmissionIdGet200ResponseSubmission
from woj.models.api_submission_post200_response import ApiSubmissionPost200Response
from woj.models.api_submission_post_request import ApiSubmissionPostRequest
from woj.models.api_sys_get200_response import ApiSysGet200Response
from woj.models.api_sys_get200_response_cfg import ApiSysGet200ResponseCfg
from woj.models.api_sys_get200_response_stat import ApiSysGet200ResponseStat



# coding: utf-8

"""
    WASM OJ Wonderland API

    You can interact with WASM OJ Wonderland through this API  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: jacob@csie.cool
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import woj
from woj.models.api_problem_id_get200_response_problem import ApiProblemIdGet200ResponseProblem  # noqa: E501
from woj.rest import ApiException

class TestApiProblemIdGet200ResponseProblem(unittest.TestCase):
    """ApiProblemIdGet200ResponseProblem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ApiProblemIdGet200ResponseProblem
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiProblemIdGet200ResponseProblem`
        """
        model = woj.models.api_problem_id_get200_response_problem.ApiProblemIdGet200ResponseProblem()  # noqa: E501
        if include_optional :
            return ApiProblemIdGet200ResponseProblem(
                name = '', 
                tags = [
                    ''
                    ], 
                description = '', 
                policy = [
                    woj.models._api_problem__id__get_200_response_problem_policy_inner._api_problem__id__get_200_response_problem_policy_inner(
                        budget = 1.337, 
                        memory = 1.337, 
                        score = 1.337, )
                    ], 
                testcase = [
                    woj.models._api_problem__id__get_200_response_problem_testcase_inner._api_problem__id__get_200_response_problem_testcase_inner(
                        score = 1.337, 
                        description = '', 
                        sample = True, 
                        stdin = '', 
                        stdout = '', 
                        stdin_file = '', 
                        stdout_file = '', )
                    ], 
                input = '', 
                output = '', 
                hint = ''
            )
        else :
            return ApiProblemIdGet200ResponseProblem(
                name = '',
                description = '',
                policy = [
                    woj.models._api_problem__id__get_200_response_problem_policy_inner._api_problem__id__get_200_response_problem_policy_inner(
                        budget = 1.337, 
                        memory = 1.337, 
                        score = 1.337, )
                    ],
                testcase = [
                    woj.models._api_problem__id__get_200_response_problem_testcase_inner._api_problem__id__get_200_response_problem_testcase_inner(
                        score = 1.337, 
                        description = '', 
                        sample = True, 
                        stdin = '', 
                        stdout = '', 
                        stdin_file = '', 
                        stdout_file = '', )
                    ],
        )
        """

    def testApiProblemIdGet200ResponseProblem(self):
        """Test ApiProblemIdGet200ResponseProblem"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    WASM OJ Wonderland API

    You can interact with WASM OJ Wonderland through this API  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: jacob@csie.cool
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist
from woj.models.api_problem_id_get200_response_problem_policy_inner import ApiProblemIdGet200ResponseProblemPolicyInner
from woj.models.api_problem_id_get200_response_problem_testcase_inner import ApiProblemIdGet200ResponseProblemTestcaseInner

class ApiProblemIdGet200ResponseProblem(BaseModel):
    """
    ApiProblemIdGet200ResponseProblem
    """
    name: StrictStr = Field(...)
    tags: Optional[conlist(StrictStr)] = None
    description: StrictStr = Field(...)
    policy: conlist(ApiProblemIdGet200ResponseProblemPolicyInner) = Field(...)
    testcase: conlist(ApiProblemIdGet200ResponseProblemTestcaseInner) = Field(...)
    input: Optional[StrictStr] = None
    output: Optional[StrictStr] = None
    hint: Optional[StrictStr] = None
    __properties = ["name", "tags", "description", "policy", "testcase", "input", "output", "hint"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiProblemIdGet200ResponseProblem:
        """Create an instance of ApiProblemIdGet200ResponseProblem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in policy (list)
        _items = []
        if self.policy:
            for _item in self.policy:
                if _item:
                    _items.append(_item.to_dict())
            _dict['policy'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in testcase (list)
        _items = []
        if self.testcase:
            for _item in self.testcase:
                if _item:
                    _items.append(_item.to_dict())
            _dict['testcase'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiProblemIdGet200ResponseProblem:
        """Create an instance of ApiProblemIdGet200ResponseProblem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiProblemIdGet200ResponseProblem.parse_obj(obj)

        _obj = ApiProblemIdGet200ResponseProblem.parse_obj({
            "name": obj.get("name"),
            "tags": obj.get("tags"),
            "description": obj.get("description"),
            "policy": [ApiProblemIdGet200ResponseProblemPolicyInner.from_dict(_item) for _item in obj.get("policy")] if obj.get("policy") is not None else None,
            "testcase": [ApiProblemIdGet200ResponseProblemTestcaseInner.from_dict(_item) for _item in obj.get("testcase")] if obj.get("testcase") is not None else None,
            "input": obj.get("input"),
            "output": obj.get("output"),
            "hint": obj.get("hint")
        })
        return _obj




# coding: utf-8

"""
    WASM OJ Wonderland API

    You can interact with WASM OJ Wonderland through this API  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: jacob@csie.cool
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import woj
from woj.models.api_submission_get200_response import ApiSubmissionGet200Response  # noqa: E501
from woj.rest import ApiException

class TestApiSubmissionGet200Response(unittest.TestCase):
    """ApiSubmissionGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ApiSubmissionGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiSubmissionGet200Response`
        """
        model = woj.models.api_submission_get200_response.ApiSubmissionGet200Response()  # noqa: E501
        if include_optional :
            return ApiSubmissionGet200Response(
                submissions = [
                    woj.models._api_submission_get_200_response_submissions_inner._api_submission_get_200_response_submissions_inner(
                        id = '', 
                        code_lang = '', 
                        problem_id = '', 
                        status = 'running', 
                        submitter_id = '', 
                        score = 1.337, 
                        cost = 1.337, 
                        memory = 1.337, )
                    ]
            )
        else :
            return ApiSubmissionGet200Response(
                submissions = [
                    woj.models._api_submission_get_200_response_submissions_inner._api_submission_get_200_response_submissions_inner(
                        id = '', 
                        code_lang = '', 
                        problem_id = '', 
                        status = 'running', 
                        submitter_id = '', 
                        score = 1.337, 
                        cost = 1.337, 
                        memory = 1.337, )
                    ],
        )
        """

    def testApiSubmissionGet200Response(self):
        """Test ApiSubmissionGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    WASM OJ Wonderland API

    You can interact with WASM OJ Wonderland through this API  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: jacob@csie.cool
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import woj
from woj.api.auth_api import AuthApi  # noqa: E501
from woj.rest import ApiException


class TestAuthApi(unittest.TestCase):
    """AuthApi unit test stubs"""

    def setUp(self):
        self.api = woj.api.auth_api.AuthApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_auth_get(self):
        """Test case for api_auth_get

        """
        pass

    def test_api_auth_send_post(self):
        """Test case for api_auth_send_post

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    WASM OJ Wonderland API

    You can interact with WASM OJ Wonderland through this API  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: jacob@csie.cool
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import woj
from woj.models.api_submission_id_get200_response_submission import ApiSubmissionIdGet200ResponseSubmission  # noqa: E501
from woj.rest import ApiException

class TestApiSubmissionIdGet200ResponseSubmission(unittest.TestCase):
    """ApiSubmissionIdGet200ResponseSubmission unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ApiSubmissionIdGet200ResponseSubmission
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiSubmissionIdGet200ResponseSubmission`
        """
        model = woj.models.api_submission_id_get200_response_submission.ApiSubmissionIdGet200ResponseSubmission()  # noqa: E501
        if include_optional :
            return ApiSubmissionIdGet200ResponseSubmission(
                id = '', 
                submitter_id = '', 
                status = 'running', 
                code = '', 
                code_lang = '', 
                problem_id = '', 
                compiler_version = '', 
                runner_version = '', 
                score = 1.337, 
                cost = 1.337, 
                memory = 1.337, 
                details = ''
            )
        else :
            return ApiSubmissionIdGet200ResponseSubmission(
                id = '',
                submitter_id = '',
                status = 'running',
                code = '',
                code_lang = '',
                problem_id = '',
                compiler_version = '',
                runner_version = '',
                score = 1.337,
                cost = 1.337,
                memory = 1.337,
                details = '',
        )
        """

    def testApiSubmissionIdGet200ResponseSubmission(self):
        """Test ApiSubmissionIdGet200ResponseSubmission"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    WASM OJ Wonderland API

    You can interact with WASM OJ Wonderland through this API  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: jacob@csie.cool
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, validator

class ApiSubmissionIdGet200ResponseSubmission(BaseModel):
    """
    ApiSubmissionIdGet200ResponseSubmission
    """
    id: StrictStr = Field(...)
    submitter_id: StrictStr = Field(...)
    status: StrictStr = Field(...)
    code: StrictStr = Field(...)
    code_lang: StrictStr = Field(...)
    problem_id: StrictStr = Field(...)
    compiler_version: StrictStr = Field(...)
    runner_version: StrictStr = Field(...)
    score: Optional[Union[StrictFloat, StrictInt]] = Field(...)
    cost: Optional[Union[StrictFloat, StrictInt]] = Field(...)
    memory: Optional[Union[StrictFloat, StrictInt]] = Field(...)
    details: Optional[StrictStr] = Field(...)
    __properties = ["id", "submitter_id", "status", "code", "code_lang", "problem_id", "compiler_version", "runner_version", "score", "cost", "memory", "details"]

    @validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('running', 'AC', 'WA', 'SLE', 'MLE', 'RE', 'error'):
            raise ValueError("must be one of enum values ('running', 'AC', 'WA', 'SLE', 'MLE', 'RE', 'error')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiSubmissionIdGet200ResponseSubmission:
        """Create an instance of ApiSubmissionIdGet200ResponseSubmission from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if score (nullable) is None
        # and __fields_set__ contains the field
        if self.score is None and "score" in self.__fields_set__:
            _dict['score'] = None

        # set to None if cost (nullable) is None
        # and __fields_set__ contains the field
        if self.cost is None and "cost" in self.__fields_set__:
            _dict['cost'] = None

        # set to None if memory (nullable) is None
        # and __fields_set__ contains the field
        if self.memory is None and "memory" in self.__fields_set__:
            _dict['memory'] = None

        # set to None if details (nullable) is None
        # and __fields_set__ contains the field
        if self.details is None and "details" in self.__fields_set__:
            _dict['details'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiSubmissionIdGet200ResponseSubmission:
        """Create an instance of ApiSubmissionIdGet200ResponseSubmission from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiSubmissionIdGet200ResponseSubmission.parse_obj(obj)

        _obj = ApiSubmissionIdGet200ResponseSubmission.parse_obj({
            "id": obj.get("id"),
            "submitter_id": obj.get("submitter_id"),
            "status": obj.get("status"),
            "code": obj.get("code"),
            "code_lang": obj.get("code_lang"),
            "problem_id": obj.get("problem_id"),
            "compiler_version": obj.get("compiler_version"),
            "runner_version": obj.get("runner_version"),
            "score": obj.get("score"),
            "cost": obj.get("cost"),
            "memory": obj.get("memory"),
            "details": obj.get("details")
        })
        return _obj




# coding: utf-8

"""
    WASM OJ Wonderland API

    You can interact with WASM OJ Wonderland through this API  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: jacob@csie.cool
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr

class ApiProblemIdGet200ResponseProblemTestcaseInner(BaseModel):
    """
    ApiProblemIdGet200ResponseProblemTestcaseInner
    """
    score: Union[StrictFloat, StrictInt] = Field(...)
    description: Optional[StrictStr] = None
    sample: Optional[StrictBool] = None
    stdin: Optional[StrictStr] = None
    stdout: Optional[StrictStr] = None
    stdin_file: Optional[StrictStr] = None
    stdout_file: Optional[StrictStr] = None
    __properties = ["score", "description", "sample", "stdin", "stdout", "stdin_file", "stdout_file"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiProblemIdGet200ResponseProblemTestcaseInner:
        """Create an instance of ApiProblemIdGet200ResponseProblemTestcaseInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiProblemIdGet200ResponseProblemTestcaseInner:
        """Create an instance of ApiProblemIdGet200ResponseProblemTestcaseInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiProblemIdGet200ResponseProblemTestcaseInner.parse_obj(obj)

        _obj = ApiProblemIdGet200ResponseProblemTestcaseInner.parse_obj({
            "score": obj.get("score"),
            "description": obj.get("description"),
            "sample": obj.get("sample"),
            "stdin": obj.get("stdin"),
            "stdout": obj.get("stdout"),
            "stdin_file": obj.get("stdin_file"),
            "stdout_file": obj.get("stdout_file")
        })
        return _obj




# coding: utf-8

# flake8: noqa
"""
    WASM OJ Wonderland API

    You can interact with WASM OJ Wonderland through this API  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: jacob@csie.cool
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


# import models into model package
from woj.models.api_auth_get200_response import ApiAuthGet200Response
from woj.models.api_auth_send_post200_response import ApiAuthSendPost200Response
from woj.models.api_auth_send_post400_response import ApiAuthSendPost400Response
from woj.models.api_auth_send_post_request import ApiAuthSendPostRequest
from woj.models.api_me_get200_response import ApiMeGet200Response
from woj.models.api_problem_get200_response import ApiProblemGet200Response
from woj.models.api_problem_get200_response_problems_inner import ApiProblemGet200ResponseProblemsInner
from woj.models.api_problem_id_get200_response import ApiProblemIdGet200Response
from woj.models.api_problem_id_get200_response_problem import ApiProblemIdGet200ResponseProblem
from woj.models.api_problem_id_get200_response_problem_policy_inner import ApiProblemIdGet200ResponseProblemPolicyInner
from woj.models.api_problem_id_get200_response_problem_testcase_inner import ApiProblemIdGet200ResponseProblemTestcaseInner
from woj.models.api_submission_get200_response import ApiSubmissionGet200Response
from woj.models.api_submission_get200_response_submissions_inner import ApiSubmissionGet200ResponseSubmissionsInner
from woj.models.api_submission_id_get200_response import ApiSubmissionIdGet200Response
from woj.models.api_submission_id_get200_response_submission import ApiSubmissionIdGet200ResponseSubmission
from woj.models.api_submission_post200_response import ApiSubmissionPost200Response
from woj.models.api_submission_post_request import ApiSubmissionPostRequest
from woj.models.api_sys_get200_response import ApiSysGet200Response
from woj.models.api_sys_get200_response_cfg import ApiSysGet200ResponseCfg
from woj.models.api_sys_get200_response_stat import ApiSysGet200ResponseStat



# coding: utf-8

"""
    WASM OJ Wonderland API

    You can interact with WASM OJ Wonderland through this API  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: jacob@csie.cool
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "woj"
VERSION = "0.0.1"
PYTHON_REQUIRES = ">=3.7"
REQUIRES = [
    "urllib3 >= 1.25.3, < 2.1.0",
    "python-dateutil",
    "pydantic >= 1.10.5, < 2",
    "aenum"
]

setup(
    name=NAME,
    version=VERSION,
    description="WASM OJ Wonderland API",
    author="Jacob Lin",
    author_email="jacob@csie.cool",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "WASM OJ Wonderland API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="MIT",
    long_description_content_type='text/markdown',
    long_description="""\
    You can interact with WASM OJ Wonderland through this API  # noqa: E501
    """,
    package_data={"woj": ["py.typed"]},
)



# coding: utf-8

"""
    WASM OJ Wonderland API

    You can interact with WASM OJ Wonderland through this API  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: jacob@csie.cool
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import woj
from woj.models.api_auth_send_post200_response import ApiAuthSendPost200Response  # noqa: E501
from woj.rest import ApiException

class TestApiAuthSendPost200Response(unittest.TestCase):
    """ApiAuthSendPost200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ApiAuthSendPost200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiAuthSendPost200Response`
        """
        model = woj.models.api_auth_send_post200_response.ApiAuthSendPost200Response()  # noqa: E501
        if include_optional :
            return ApiAuthSendPost200Response(
                ok = True, 
                send = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else :
            return ApiAuthSendPost200Response(
                ok = True,
                send = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testApiAuthSendPost200Response(self):
        """Test ApiAuthSendPost200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    WASM OJ Wonderland API

    You can interact with WASM OJ Wonderland through this API  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: jacob@csie.cool
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import woj
from woj.models.api_problem_id_get200_response import ApiProblemIdGet200Response  # noqa: E501
from woj.rest import ApiException

class TestApiProblemIdGet200Response(unittest.TestCase):
    """ApiProblemIdGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ApiProblemIdGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiProblemIdGet200Response`
        """
        model = woj.models.api_problem_id_get200_response.ApiProblemIdGet200Response()  # noqa: E501
        if include_optional :
            return ApiProblemIdGet200Response(
                problem = woj.models._api_problem__id__get_200_response_problem._api_problem__id__get_200_response_problem(
                    name = '', 
                    tags = [
                        ''
                        ], 
                    description = '', 
                    policy = [
                        woj.models._api_problem__id__get_200_response_problem_policy_inner._api_problem__id__get_200_response_problem_policy_inner(
                            budget = 1.337, 
                            memory = 1.337, 
                            score = 1.337, )
                        ], 
                    testcase = [
                        woj.models._api_problem__id__get_200_response_problem_testcase_inner._api_problem__id__get_200_response_problem_testcase_inner(
                            score = 1.337, 
                            description = '', 
                            sample = True, 
                            stdin = '', 
                            stdout = '', 
                            stdin_file = '', 
                            stdout_file = '', )
                        ], 
                    input = '', 
                    output = '', 
                    hint = '', )
            )
        else :
            return ApiProblemIdGet200Response(
                problem = woj.models._api_problem__id__get_200_response_problem._api_problem__id__get_200_response_problem(
                    name = '', 
                    tags = [
                        ''
                        ], 
                    description = '', 
                    policy = [
                        woj.models._api_problem__id__get_200_response_problem_policy_inner._api_problem__id__get_200_response_problem_policy_inner(
                            budget = 1.337, 
                            memory = 1.337, 
                            score = 1.337, )
                        ], 
                    testcase = [
                        woj.models._api_problem__id__get_200_response_problem_testcase_inner._api_problem__id__get_200_response_problem_testcase_inner(
                            score = 1.337, 
                            description = '', 
                            sample = True, 
                            stdin = '', 
                            stdout = '', 
                            stdin_file = '', 
                            stdout_file = '', )
                        ], 
                    input = '', 
                    output = '', 
                    hint = '', ),
        )
        """

    def testApiProblemIdGet200Response(self):
        """Test ApiProblemIdGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    WASM OJ Wonderland API

    You can interact with WASM OJ Wonderland through this API  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: jacob@csie.cool
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr

class ApiMeGet200Response(BaseModel):
    """
    ApiMeGet200Response
    """
    id: Optional[StrictStr] = Field(None, description="User ID")
    email: Optional[StrictStr] = Field(None, description="User's email")
    exp: Optional[Union[StrictFloat, StrictInt]] = Field(None, description="Token expiration time, in seconds since epoch")
    pea: StrictStr = Field(..., description="The PEA login URL that this app uses")
    __properties = ["id", "email", "exp", "pea"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiMeGet200Response:
        """Create an instance of ApiMeGet200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiMeGet200Response:
        """Create an instance of ApiMeGet200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiMeGet200Response.parse_obj(obj)

        _obj = ApiMeGet200Response.parse_obj({
            "id": obj.get("id"),
            "email": obj.get("email"),
            "exp": obj.get("exp"),
            "pea": obj.get("pea")
        })
        return _obj




# flake8: noqa

# import apis into api package
from woj.api.auth_api import AuthApi
from woj.api.problem_api import ProblemApi
from woj.api.submission_api import SubmissionApi
from woj.api.default_api import DefaultApi




# coding: utf-8

"""
    WASM OJ Wonderland API

    You can interact with WASM OJ Wonderland through this API  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: jacob@csie.cool
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictStr, constr, validator

class ApiSubmissionPostRequest(BaseModel):
    """
    ApiSubmissionPostRequest
    """
    problem: constr(strict=True, max_length=128, min_length=1) = Field(..., description="Problem ID")
    code: constr(strict=True, max_length=16384, min_length=1) = Field(..., description="Source code")
    lang: StrictStr = Field(..., description="Programming language of the source code")
    __properties = ["problem", "code", "lang"]

    @validator('lang')
    def lang_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('rs', 'c', 'cpp'):
            raise ValueError("must be one of enum values ('rs', 'c', 'cpp')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiSubmissionPostRequest:
        """Create an instance of ApiSubmissionPostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiSubmissionPostRequest:
        """Create an instance of ApiSubmissionPostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiSubmissionPostRequest.parse_obj(obj)

        _obj = ApiSubmissionPostRequest.parse_obj({
            "problem": obj.get("problem"),
            "code": obj.get("code"),
            "lang": obj.get("lang")
        })
        return _obj

